==> xlniuxdata-vipgame-1.0.33-sources.jar: com/xunlei/niux/data/vipgame/dto/vic/CustomerWarningLostLoginDTO.java <==
package com.xunlei.niux.data.vipgame.dto.vic;

public class CustomerWarningLostLoginDTO {
    private String uid;
    private Integer vipGrade;
    private String lastLoginTime;
    private String lastPayTime;
    private Long lastModifyAmt;
    private String payGameId;
    private String loginGameId;
    private String lastCaller;
    private String lastCallTime;
    private String customerService;
    private String lostLogin;
    private String firstTreatLogin;
    private String firstTreatResultLogin;
    private String secondTreatLogin;
    private String secondTreatResultLogin;
    private Integer lostLoginDays;
    private Integer lostPayDays;

    public String getLoginGameId() {
        return loginGameId;
    }

    public void setLoginGameId(String loginGameId) {
        this.loginGameId = loginGameId;
    }

    public String getCustomerService() {
        return customerService;
    }

    public void setCustomerService(String customerService) {
        this.customerService = customerService;
    }

    public String getFirstTreatLogin() {
        return firstTreatLogin;
    }

    public void setFirstTreatLogin(String firstTreatLogin) {
        this.firstTreatLogin = firstTreatLogin;
    }

    public String getFirstTreatResultLogin() {
        return firstTreatResultLogin;
    }

    public void setFirstTreatResultLogin(String firstTreatResultLogin) {
        this.firstTreatResultLogin = firstTreatResultLogin;
    }

    public String getLastCaller() {
        return lastCaller;
    }

    public void setLastCaller(String lastCaller) {
        this.lastCaller = lastCaller;
    }

    public String getLastCallTime() {
        return lastCallTime;
    }

    public void setLastCallTime(String lastCallTime) {
        this.lastCallTime = lastCallTime;
    }

    public String getLastLoginTime() {
        return lastLoginTime;
    }

    public void setLastLoginTime(String lastLoginTime) {
        this.lastLoginTime = lastLoginTime;
    }

    public Long getLastModifyAmt() {
        return lastModifyAmt;
    }

    public void setLastModifyAmt(Long lastModifyAmt) {
        this.lastModifyAmt = lastModifyAmt;
    }

    public String getLastPayTime() {
        return lastPayTime;
    }

    public void setLastPayTime(String lastPayTime) {
        this.lastPayTime = lastPayTime;
    }

    public String getLostLogin() {
        return lostLogin;
    }

    public void setLostLogin(String lostLogin) {
        this.lostLogin = lostLogin;
    }

    public Integer getLostLoginDays() {
        return lostLoginDays;
    }

    public void setLostLoginDays(Integer lostLoginDays) {
        this.lostLoginDays = lostLoginDays;
    }

    public Integer getLostPayDays() {
        return lostPayDays;
    }

    public void setLostPayDays(Integer lostPayDays) {
        this.lostPayDays = lostPayDays;
    }

    public String getPayGameId() {
        return payGameId;
    }

    public void setPayGameId(String payGameId) {
        this.payGameId = payGameId;
    }

    public String getSecondTreatLogin() {
        return secondTreatLogin;
    }

    public void setSecondTreatLogin(String secondTreatLogin) {
        this.secondTreatLogin = secondTreatLogin;
    }

    public String getSecondTreatResultLogin() {
        return secondTreatResultLogin;
    }

    public void setSecondTreatResultLogin(String secondTreatResultLogin) {
        this.secondTreatResultLogin = secondTreatResultLogin;
    }

    public String getUid() {
        return uid;
    }

    public void setUid(String uid) {
        this.uid = uid;
    }

    public Integer getVipGrade() {
        return vipGrade;
    }

    public void setVipGrade(Integer vipGrade) {
        this.vipGrade = vipGrade;
    }
}

==> xlniuxdata-vipgame-1.0.33-20151110.124833-15-sources.jar: com/xunlei/niux/data/vipgame/dto/vic/CustomerWarningLostLoginDTO.java <==
package com.xunlei.niux.data.vipgame.dto.vic;

public class CustomerWarningLostLoginDTO {
    private String uid;
    private Integer vipGrade;
    private String lastLoginTime;
    private String lastPayTime;
    private Long lastModifyAmt;
    private String payGameId;
    private String loginGameId;
    private String lastCaller;
    private String lastCallTime;
    private String customerService;
    private String lostLogin;
    private String firstTreatLogin;
    private String firstTreatResultLogin;
    private String secondTreatLogin;
    private String secondTreatResultLogin;
    private Integer lostLoginDays;
    private Integer lostPayDays;
    private Integer loginPayType;

    public Integer getLoginPayType() {
        return loginPayType;
    }

    public void setLoginPayType(Integer loginPayType) {
        this.loginPayType = loginPayType;
    }

    public String getLoginGameId() {
        return loginGameId;
    }

    public void setLoginGameId(String loginGameId) {
        this.loginGameId = loginGameId;
    }

    public String getCustomerService() {
        return customerService;
    }

    public void setCustomerService(String customerService) {
        this.customerService = customerService;
    }

    public String getFirstTreatLogin() {
        return firstTreatLogin;
    }

    public void setFirstTreatLogin(String firstTreatLogin) {
        this.firstTreatLogin = firstTreatLogin;
    }

    public String getFirstTreatResultLogin() {
        return firstTreatResultLogin;
    }

    public void setFirstTreatResultLogin(String firstTreatResultLogin) {
        this.firstTreatResultLogin = firstTreatResultLogin;
    }

    public String getLastCaller() {
        return lastCaller;
    }

    public void setLastCaller(String lastCaller) {
        this.lastCaller = lastCaller;
    }

    public String getLastCallTime() {
        return lastCallTime;
    }

    public void setLastCallTime(String lastCallTime) {
        this.lastCallTime = lastCallTime;
    }

    public String getLastLoginTime() {
        return lastLoginTime;
    }

    public void setLastLoginTime(String lastLoginTime) {
        this.lastLoginTime = lastLoginTime;
    }

    public Long getLastModifyAmt() {
        return lastModifyAmt;
    }

    public void setLastModifyAmt(Long lastModifyAmt) {
        this.lastModifyAmt = lastModifyAmt;
    }

    public String getLastPayTime() {
        return lastPayTime;
    }

    public void setLastPayTime(String lastPayTime) {
        this.lastPayTime = lastPayTime;
    }

    public String getLostLogin() {
        return lostLogin;
    }

    public void setLostLogin(String lostLogin) {
        this.lostLogin = lostLogin;
    }

    public Integer getLostLoginDays() {
        return lostLoginDays;
    }

    public void setLostLoginDays(Integer lostLoginDays) {
        this.lostLoginDays = lostLoginDays;
    }

    public Integer getLostPayDays() {
        return lostPayDays;
    }

    public void setLostPayDays(Integer lostPayDays) {
        this.lostPayDays = lostPayDays;
    }

    public String getPayGameId() {
        return payGameId;
    }

    public void setPayGameId(String payGameId) {
        this.payGameId = payGameId;
    }

    public String getSecondTreatLogin() {
        return secondTreatLogin;
    }

    public void setSecondTreatLogin(String secondTreatLogin) {
        this.secondTreatLogin = secondTreatLogin;
    }

    public String getSecondTreatResultLogin() {
        return secondTreatResultLogin;
    }

    public void setSecondTreatResultLogin(String secondTreatResultLogin) {
        this.secondTreatResultLogin = secondTreatResultLogin;
    }

    public String getUid() {
        return uid;
    }

    public void setUid(String uid) {
        this.uid = uid;
    }

    public Integer getVipGrade() {
        return vipGrade;
    }

    public void setVipGrade(Integer vipGrade) {
        this.vipGrade = vipGrade;
    }
}
